@@ -6,13 +6,11 @@ use 5.008_004;
 use strict;
 use warnings FATAL => 'all';
 
-use Data::Dumper;
-
 use Data::Walk qw( walk );
 use List::Util qw( shuffle );
 use String::Random qw( random_regex );
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Guarantee that toposort is loaded.
 use base 'DBIx::Class::TopoSort';
@@ -22,12 +20,10 @@ use base 'DBIx::Class::TopoSort';
 
   sub set_sim_type {
     shift;
+    my $types = shift;
+    return unless ref($types||'') eq 'HASH';
 
-    while ( @_ ) {
-      my $name = shift;
-      return unless @_;
-
-      my $meth = shift;
+    while ( my ($name, $meth) = each(%$types) ) {
       next unless ref($meth) eq 'CODE';
 
       $sim_types{$name} = $meth;
@@ -35,7 +31,7 @@ use base 'DBIx::Class::TopoSort';
 
     return;
   }
-  *set_sim_types = \&set_sim_type;
+  BEGIN { *set_sim_types = \&set_sim_type; }
 
   sub sim_type {
     shift;
@@ -44,7 +40,7 @@ use base 'DBIx::Class::TopoSort';
     return $sim_types{$_[0]} if @_ == 1;
     return map { $sim_types{$_} } @_;
   }
-  *sim_types = \&sim_type;
+  BEGIN { *sim_types = \&sim_type; }
 }
 use DBIx::Class::Sims::Types;
 
@@ -370,7 +366,9 @@ for testing purposes (though, obviously, it's not limited to just test data).
 
 =head1 METHODS
 
-=head2 $rv = $schema->load_sims( $spec, ?$constraints, ?$hooks )
+=head2 load_sims
+
+C<< $rv = $schema->load_sims( $spec, ?$constraints, ?$hooks ) >>
 
 This method will load the rows requested in C<$spec>, plus any additional rows
 necessary to make those rows work. This includes any parent rows (as defined by
@@ -428,7 +426,9 @@ You will receive back (assuming the next PK values are as below):
 Note that you do not get back the ids for any additional rows generated (such as
 for the children). 
 
-=head2 $class_or_obj->set_sim_type({ $name => $handler, ... });
+=head2 set_sim_type
+
+C<< $class_or_obj->set_sim_type({ $name => $handler, ... }); >>
 
 This method will set the handler for the C<$name> sim type. The handler must be
 a reference to a subroutine. You may pass in as many name/handler pairs as you
@@ -531,6 +531,56 @@ The following sim types are pre-defined:
 
 =over 4
 
+=item * us_address
+
+This generates a reasonable-looking US street address. The address will be one
+of these forms:
+
+=over 4
+
+=item * "#### Name Type", so something like "123 Main Street"
+
+=item * "PO Box ####", so something like "PO Box 13579"
+
+=item * "P.O. Box ####", so something like "P.O. Box 97531"
+
+=back
+
+=item * us_county
+
+This generates a reasonable-looking US county name.
+
+=item * us_name
+
+This generates a reasonable-looking US person name. The name will contain a
+first name, a last name, and possibly a suffix. The first name will be
+randomized as to gender and the last name may contain one word, two words, or an
+apostrophized word.
+
+=item * us_phone
+
+This generates a reasonable-looking US phone-number, based on the size of the
+column being filled. The column is assumed to be a character-type column
+(varchar, etc). If the size of the column is less than 10, there will be no area
+code. If there is space, hyphens and parentheses will be added in the right
+places. If the column is long enough, the value will look like "(###) ###-####"
+
+Phone extensions are not supported at this time.
+
+=item * us_ssntin
+
+This generates a reasonable-looking US Social Security Number (SSN) or Tax
+Identification Number (TIN). These are government identifiers that are often
+usable as unique personal IDs. An SSN is a personal ID number and a TIN is a
+corporate ID number.
+
+=item * us_state
+
+This generates a random US state or territory (so 57 choices). The column is
+assumed to be able to take a US state as a value. If the size of the column is 2
+(the default), then the abbreviation will be returned. Otherwise, the first N
+characters of the name (where N is the size) will be returned.
+
 =item * us_zipcode
 
 This generates a reasonable-looking US zipcode. If the column is numeric, it
@@ -540,6 +590,23 @@ width.
 
 =back
 
+The reason why the pre-defined sim types have the country prefixed is because
+different countries do things differently. (Shocker, I know!)
+
+=head1 TODO
+
+=head2 Multi-column types
+
+In some applications, columns like "state" and "zipcode" are correlated. Values
+for one must be legal for the value in the other. The Sims currently has no way
+of generating correlated columns like this.
+
+=head1 BUGS/SUGGESTIONS
+
+This module is hosted on Github at
+L<https://github.com/robkinyon/dbix-class-sims>. Pull requests are strongly
+encouraged.
+
 =head1 DBIx::Class::Fixtures
 
 L<DBIx::Class::Fixtures> is another way to load data into a database. Unlike
